@@ -31,7 +31,7 @@ class DateTimeClock(clock.Clock):
         clock.Clock.__init__(self, drawing_area)
 
     def draw_clock(self):
-        self.context.set_font_size(20)
+        self.context.set_font_size(int(self.text_scaling * 20))
 
 # Draw date.
         self.context.move_to(2, 16)
@@ -73,7 +73,7 @@ class DateTimeClock(clock.Clock):
           self.context.stroke()
 
         if self.twelve_hour_mode :
-            self.context.set_font_size(10)
+            self.context.set_font_size(int(self.text_scaling * 10))
             self.context.move_to(self.text_width, 35)
             
             self.context.text_path(abrv)
@@ -84,7 +84,7 @@ class DateTimeClock(clock.Clock):
                 self.context.stroke()
 
     def resize(self):
-        self.context.set_font_size(20)
+        self.context.set_font_size(int(self.text_scaling * 20))
         if self.show_seconds :
             self.text_width = self.context.text_extents("00:00:00")[2]
         else:
@@ -94,7 +94,7 @@ class DateTimeClock(clock.Clock):
 
         if self.twelve_hour_mode :
             self.text_width += self.context.text_extents("..")[2]
-            self.context.set_font_size(10)
+            self.context.set_font_size(int(self.text_scaling * 10))
             self.abrv_width = self.context.text_extents("AM")[2]
             self.abrv_width *= 1.1
         else :
